@@ -6,6 +6,7 @@ import matplotlib.pyplot as plt
 import numpy
 from tqdm import tqdm
 
+import cleanplotlib as cpl
 import termtables as tt
 
 # Orders of Magnitude for SI time units in {unit: magnitude} format
@@ -62,12 +63,7 @@ class PerfplotData:
         self.title = title
 
     def plot(  # noqa: C901
-        self,
-        automatic_order=True,
-        time_unit="s",
-        relative_to=None,
-        logx="auto",
-        logy="auto",
+        self, time_unit="s", relative_to=None, logx="auto", logy="auto",
     ):
         if logx == "auto":
             # Check if the x values are approximately equally spaced in log
@@ -85,27 +81,7 @@ class PerfplotData:
             else:
                 logy = logx
 
-        # choose plot function
-        if logx and logy:
-            plotfun = plt.loglog
-        elif logx:
-            plotfun = plt.semilogx
-        elif logy:
-            plotfun = plt.semilogy
-        else:
-            plotfun = plt.plot
-
         if self.flop is None:
-            if automatic_order:
-                # Sort timings by the last entry. This makes the order in the legend
-                # correspond to the order of the lines.
-                order = numpy.argsort(self.timings[:, -1])[::-1]
-                if relative_to is not None:
-                    relative_to = numpy.where(order == relative_to)[0][0]
-                self.timings = self.timings[order]
-                self.labels = [self.labels[i] for i in order]
-                self.colors = [self.colors[i] for i in order]
-
             if relative_to is None:
                 # Set time unit of plots. Allowed values: ("s", "ms", "us", "ns", "auto")
                 if time_unit == "auto":
@@ -114,42 +90,36 @@ class PerfplotData:
                     assert time_unit in si_time, "Provided `time_unit` is not valid"
 
                 scaled_timings = self.timings * (si_time["ns"] / si_time[time_unit])
-                plt.ylabel(f"Runtime [{time_unit}]")
+                cpl.ylabel(f"Runtime [{time_unit}]")
             else:
                 scaled_timings = self.timings / self.timings[relative_to]
-                plt.ylabel(f"Runtime relative to {self.labels[relative_to]}")
+                cpl.ylabel(f"Runtime relative to {self.labels[relative_to]}()")
 
-            for t, label, color in zip(scaled_timings, self.labels, self.colors):
-                plotfun(self.n_range, t, label=label, color=color)
+            cpl.multiplot(
+                [self.n_range] * len(scaled_timings),
+                scaled_timings,
+                self.labels,
+                logx=logx,
+                logy=logy,
+            )
         else:
-            if automatic_order:
-                # Sort timings by the last entry. This makes the order in the legend
-                # correspond to the order of the lines.
-                order = numpy.argsort(self.timings[:, -1])
-                if relative_to is not None:
-                    relative_to = numpy.where(order == relative_to)[0][0]
-                self.timings = self.timings[order]
-                self.labels = [self.labels[i] for i in order]
-                self.colors = [self.colors[i] for i in order]
-
             if relative_to is None:
-                flops = self.flop / self.timings / 1.0e-9
-                plt.ylabel("FLOPS")
+                flops = self.flop / self.timings / si_time["ns"]
+                cpl.ylabel("FLOPS")
             else:
                 flops = self.timings[relative_to] / self.timings
-                plt.ylabel(f"FLOPS relative to {self.labels[relative_to]}")
+                cpl.ylabel(f"FLOPS relative to {self.labels[relative_to]}")
 
-            for fl, label, color in zip(flops, self.labels, self.colors):
-                plotfun(self.n_range, fl, label=label, color=color)
+            cpl.multiplot(
+                [self.n_range] * len(flops), flops, self.labels, logx=logx, logy=logy
+            )
 
         if self.xlabel:
-            plt.xlabel(self.xlabel)
+            cpl.xlabel(self.xlabel)
         if self.title:
             plt.title(self.title)
-        if relative_to is not None:
+        if relative_to is not None and not logy:
             plt.gca().set_ylim(bottom=0)
-        plt.grid(True)
-        plt.legend()
 
     def show(self, **kwargs):
         self.plot(**kwargs)
@@ -192,7 +162,7 @@ def bench(
         # Estimate the timer resolution by measuring a no-op.
         number = 100
         noop_time = timeit.repeat(repeat=10, number=number, timer=timer)
-        resolution = numpy.min(noop_time) / number * 1.0e9
+        resolution = numpy.min(noop_time) / number / si_time["ns"]
         # round up to nearest integer
         resolution = -int(-resolution // 1)  # typically around 10 (ns)
 
@@ -218,7 +188,7 @@ def bench(
                 # time, append as many repeats as the first measurements suggests.
                 # If the kernel is fast, the measurement with one repetition only can
                 # be somewhat off, but most of the time it's good enough.
-                remaining_time = int(target_time_per_measurement * 1.0e9)
+                remaining_time = int(target_time_per_measurement / si_time["ns"])
 
                 repeat = 1
                 t, total_time = _b(data, kernel, repeat, timer, is_ns_timer, resolution)
@@ -247,6 +217,7 @@ def _b(data, kernel, repeat, timer, is_ns_timer, resolution):
     number = 1
     required_timing = 10 * resolution
     min_timing = 0
+
     while min_timing <= required_timing:
         tm = numpy.array(
             timeit.repeat(
@@ -254,7 +225,7 @@ def _b(data, kernel, repeat, timer, is_ns_timer, resolution):
             )
         )
         if not is_ns_timer:
-            tm *= 1.0e9
+            tm /= si_time["ns"]
             tm = tm.astype(int)
         min_timing = numpy.min(tm)
         # plt.title("number={} repeat={}".format(number, repeat))
@@ -268,14 +239,17 @@ def _b(data, kernel, repeat, timer, is_ns_timer, resolution):
         # to an allowance of 0.2).
         allowance = 0.2
         max_factor = 100
-        # The next expression is
-        #   min(max_factor, required_timing / min_timing + allowance)
-        # with avoiding division by 0 if min_timing is too small.
-        factor = (
-            required_timing / min_timing + allowance
-            if min_timing > required_timing / (max_factor - allowance)
-            else max_factor
-        )
+        factor = max_factor
+        if min_timing > 0:
+            # The next expression is
+            #   min(max_factor, required_timing / min_timing + allowance)
+            # with avoiding division by 0 if min_timing is too small.
+            factor = (
+                required_timing / min_timing + allowance
+                if min_timing > required_timing / (max_factor - allowance)
+                else max_factor
+            )
+
         number = int(factor * number) + 1
 
     # Only return the minimum time; everthing else just measures
@@ -285,40 +259,20 @@ def _b(data, kernel, repeat, timer, is_ns_timer, resolution):
 
 # For backward compatibility:
 def plot(
-    *args,
-    time_unit="s",
-    logx="auto",
-    logy="auto",
-    relative_to=None,
-    automatic_order=True,
-    **kwargs,
+    *args, time_unit="s", logx="auto", logy="auto", relative_to=None, **kwargs,
 ):
     out = bench(*args, **kwargs)
     out.plot(
-        time_unit=time_unit,
-        logx=logx,
-        logy=logy,
-        relative_to=relative_to,
-        automatic_order=automatic_order,
+        time_unit=time_unit, logx=logx, logy=logy, relative_to=relative_to,
     )
 
 
 def show(
-    *args,
-    time_unit="s",
-    relative_to=None,
-    logx="auto",
-    logy="auto",
-    automatic_order=True,
-    **kwargs,
+    *args, time_unit="s", relative_to=None, logx="auto", logy="auto", **kwargs,
 ):
     out = bench(*args, **kwargs)
     out.show(
-        time_unit=time_unit,
-        relative_to=relative_to,
-        logx=logx,
-        logy=logy,
-        automatic_order=automatic_order,
+        time_unit=time_unit, relative_to=relative_to, logx=logx, logy=logy,
     )
 
 
@@ -330,7 +284,6 @@ def save(
     logx="auto",
     logy="auto",
     relative_to=None,
-    automatic_order=True,
     **kwargs,
 ):
     out = bench(*args, **kwargs)
@@ -341,5 +294,4 @@ def save(
         logx=logx,
         logy=logy,
         relative_to=relative_to,
-        automatic_order=automatic_order,
     )
